@@ -2,7 +2,7 @@
 _SPIRV_OP(Success, "")
 _SPIRV_OP(InvalidTargetTriple,
           "Expects spir-unknown-unknown or spir64-unknown-unknown.")
-_SPIRV_OP(InvalidSubArch, "Expecting v1.0-v1.5.")
+_SPIRV_OP(InvalidSubArch, "Expecting v1.0-v1.6.")
 _SPIRV_OP(TripleMaxVersionIncompatible,
           "Triple version and maximum version are incompatible.")
 _SPIRV_OP(InvalidAddressingModel, "Expects 0-2.")
@@ -23,3 +23,9 @@ _SPIRV_OP(Requires1_1, "Feature requires SPIR-V 1.1 or greater:")
 _SPIRV_OP(RequiresVersion, "Cannot fulfill SPIR-V version restriction:\n")
 _SPIRV_OP(RequiresExtension,
           "Feature requires the following SPIR-V extension:\n")
+_SPIRV_OP(InvalidMagicNumber,
+          "Invalid Magic Number.")
+_SPIRV_OP(InvalidVersionNumber,
+          "Invalid Version Number.")
+_SPIRV_OP(UnspecifiedMemoryModel, "Unspecified Memory Model.")
+_SPIRV_OP(RepeatedMemoryModel, "Expects a single OpMemoryModel instruction.")
